@@ -1,7 +1,7 @@
 package Plack::Middleware::Deflater;
 use strict;
 use 5.008001;
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 use parent qw(Plack::Middleware);
 use Plack::Util::Accessor qw( content_type vary_user_agent);
 
@@ -25,9 +25,6 @@ sub call {
     $self->response_cb($res, sub {
         my $res = shift;
 
-        # do not support streaming response
-        return unless defined $res->[2];
-
         # can't operate on Content-Ranges
         return if $env->{HTTP_CONTENT_RANGE};
 
